@@ -28,7 +28,7 @@ from jupyter_client.connect import ConnectionFileMixin
 from jupyter_client.session import Session, session_aliases, session_flags
 from jupyter_core.paths import jupyter_runtime_dir
 from tornado import ioloop
-from traitlets import (
+from traitlets.traitlets import (
     Any,
     Bool,
     Dict,
@@ -212,7 +212,7 @@ class IPKernelApp(BaseIPythonApplication, InteractiveShellApp, ConnectionFileMix
             self.poller = ParentPollerUnix()
 
     def _try_bind_socket(self, s, port):
-        iface = "%s://%s" % (self.transport, self.ip)
+        iface = f"{self.transport}://{self.ip}"
         if self.transport == "tcp":
             if port <= 0:
                 port = s.bind_to_random_port(iface)
